<?php
/*
Plugin Name: Sandwich AdSense
Plugin URI: https://github.com/mon8co/SandwichAdsense
Description: This is a WordPress plugin to insert Google AdSense code in your blog entry.
Author: Minoru Wada
Version: 4.0.2
Text domain: firsth3tagadsense
Author URI: http://monhaco.com
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/
define('H2_REG', "/<h2.*?>[^<]*<\/h2>/i"); //h2Tag
define('H3_REG', "/<h3.*?>[^<]*<\/h3>/i"); //h3Tag
define('H4_REG', "/<h4.*?>[^<]*<\/h4>/i"); //h4Tag
define('VERSION_NO', '4.0');

$Fhas = new FirstH3TagAdsense();

add_action('admin_menu',array($Fhas,'my_admin_menu'));

class FirstH3TagAdsense {
	//コンストラクタ
	function __construct() {
		add_action( 'plugins_loaded', array( &$this, 'initialize' ) );
	}
	//初期化処理
	function initialize() {
		add_action('admin_init', array($this,'my_admin_init'));
		add_filter('admin_init', array($this,'add_custom_whitelist_options_fields' ));
		add_filter('the_content', array($this,'add_ads_before_1st_h3'));
	
		if ( function_exists('register_uninstall_hook') )  {
    		register_uninstall_hook(__FILE__, 'FirstH3TagAdsense::my_uninstall_hook');
		}
    }
	function my_admin_menu() {
	add_options_page (
			__('Sandwich Adsense', 'firsth3tagadsense'),
			__('Sandwich Adsense', 'firsth3tagadsense'),
			'manage_options',
			'Sandwich Adsense',
			array($this,'my_submenu')
			);
	}
	
	function my_submenu() {
		    $options_tag = get_option("tagtype");
		    $options_locate = get_option("taglocate");
		?>
		    <div class="wrap">
		    <h1><?php esc_html_e('Sandwich AdSense', 'firsth3tagadsense'); ?> <?php printf(__('(Version %s)', 'firsth3tagadsense'), VERSION_NO); ?></h1>
		    <h2><?php esc_html_e('Ads Code Setting', 'firsth3tagadsense'); ?></h2>
		    <form id="my-submenu-form" method="post" action="">
		    	<?php wp_nonce_field('my-nonce-key','FirstH3TagAdsense'); ?>
		    	<?php esc_html_e('Target tag', 'firsth3tagadsense'); ?>
		    	<select name="tagtype">
		    		<option value="h2tag" <?php selected( $options_tag, "h2tag" ); ?>>H2</option>
					<option value="h3tag" <?php selected( $options_tag, "h3tag" ); ?>>H3</option>
					<option value="h4tag" <?php selected( $options_tag, "h4tag" ); ?>>H4</option>
				</select><p/>
				<?php esc_html_e('Ad place from Tag', 'firsth3tagadsense'); ?>
				<select name="taglocate">
		    		<option value="above" <?php selected( $options_tag, "above" ); ?>><?php esc_html_e('above', 'firsth3tagadsense'); ?></option>
					<option value="under" <?php selected( $options_tag, "under" ); ?>><?php esc_html_e('under', 'firsth3tagadsense'); ?></option>
				</select><p/>
				<?php esc_html_e('Escape Ads Tag(Ads will not be inserted into articles containing this tag)', 'firsth3tagadsense'); ?><p/>
					<textarea name="escape_tag" id="escape_tag" cols="100" rows="1"><?php 
					$esctag = get_option('escape_tag');
					if ( esctag ) {
						echo esc_textarea(stripslashes(get_option('escape_tag')));
					} 
					?></textarea><p/>
				<p/>
				<h2><?php esc_html_e('Below is the ad setting area for PC.', 'firsth3tagadsense'); ?></h2>
				<h4><?php printf(__('1st Ad Code (%s)', 'firsth3tagadsense'), __('PC', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code" id="adsense_code" cols="100" rows="10"><?php 
					$adparam1 = get_option('adsense_code');
					if ( adparam1 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code'))); 
					} 					
					?></textarea><p/>

				<h4><?php printf(__('2nd Ad Code (%s)', 'firsth3tagadsense'), __('PC', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code2" id="adsense_code2" cols="100" rows="10"><?php 
					$adparam2 = get_option('adsense_code2');
					if ( adparam2 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code2'))); 
					}
					?></textarea><p/>
				<h4><?php printf(__('3rd Ad Code (%s)', 'firsth3tagadsense'), __('PC', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code3" id="adsense_code3" cols="100" rows="10"><?php 
					$adparam3 = get_option('adsense_code3');
					if ( adparam3 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code3'))); 
					}
					?></textarea><p/>
				<h4><?php printf(__('4th Ad Code (%s)', 'firsth3tagadsense'), __('PC', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code4" id="adsense_code4" cols="100" rows="10"><?php 
					$adparam4 = get_option('adsense_code4');
					if ( adparam4 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code4'))); 
					}
					?></textarea><p/>
				<h4><?php printf(__('5th Ad Code (%s)', 'firsth3tagadsense'), __('PC', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code5" id="adsense_code5" cols="100" rows="10"><?php 
					$adparam5 = get_option('adsense_code5');
					if ( adparam5 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code5'))); 
					}
					?></textarea><p/>
				<h2><?php esc_html_e('Below is the ad setting area for mobile.', 'firsth3tagadsense'); ?></h2>
				<h4><?php printf(__('1st Ad Code (%s)', 'firsth3tagadsense'), __('mobile', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code_mobile" id="adsense_code_mobile" cols="100" rows="10"><?php 
					$adparam_m1 = get_option('adsense_code_mobile');
					if ( adparam_m1 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code_mobile'))); 
					}
					?></textarea><p/>
				<h4><?php printf(__('2nd Ad Code (%s)', 'firsth3tagadsense'), __('mobile', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code_mobile2" id="adsense_code_mobile2" cols="100" rows="10"><?php 
					$adparam_m2 = get_option('adsense_code_mobile2');
					if ( adparam_m2 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code_mobile2'))); 
					}
					?></textarea><p/>
				<h4><?php printf(__('3rd Ad Code (%s)', 'firsth3tagadsense'), __('mobile', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code_mobile3" id="adsense_code_mobile3" cols="100" rows="10"><?php 
					$adparam_m3 = get_option('adsense_code_mobile3');
					if ( adparam_m3 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code_mobile3'))); 
					} 
					?></textarea><p/>
				<h4><?php printf(__('4th Ad Code (%s)', 'firsth3tagadsense'), __('mobile', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code_mobile4" id="adsense_code_mobile4" cols="100" rows="10"><?php 
					$adparam_m4 = get_option('adsense_code_mobile4');
					if ( adparam_m4 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code_mobile4'))); 
					} 
					?></textarea><p/>
				<h4><?php printf(__('5th Ad Code (%s)', 'firsth3tagadsense'), __('mobile', 'firsth3tagadsense')); ?></h4>
					<textarea name="adsense_code_mobile5" id="adsense_code_mobile5" cols="100" rows="10"><?php 
					$adparam_m4 = get_option('adsense_code_mobile5');
					if ( adparam_m5 ) {
						echo esc_textarea(stripslashes(get_option('adsense_code_mobile5'))); 
					} 
					?></textarea><p/>
		  		<input type="submit" value="<?php esc_html_e('Save', 'firsth3tagadsense'); ?>">
		  		<div><?php printf(__('This Plugin made by Minoru Wada @monhaco(%s)', 'firsth3tagadsense'), '<a href="http://monhaco.com">http://monhaco.com</a>'); ?></div>
		  	</form>
		  	</div>
		 <?php
	}

	function my_admin_init() {

		if (isset($_POST['tagtype'])) {
	   			update_option('tagtype',$_POST['tagtype']);
	   	}

	   	if (isset($_POST['taglocate'])) {
	   			update_option('taglocate',$_POST['taglocate']);
	    }

		if (isset($_POST['escape_tag'])) {
	   			update_option('escape_tag',stripslashes($_POST['escape_tag']));
	    }
		
		if (isset($_POST['adsense_code']) ) {
			   update_option('adsense_code',stripslashes($_POST['adsense_code']));
		} 

		if (isset($_POST['adsense_code2']) ) {
	 			update_option('adsense_code2',stripslashes($_POST['adsense_code2']));
	 	} 

	 	if (isset($_POST['adsense_code3']) ) {
	 			update_option('adsense_code3',stripslashes($_POST['adsense_code3']));
	 	} 	

	 	if (isset($_POST['adsense_code4']) ) {
	 			update_option('adsense_code4',stripslashes($_POST['adsense_code4']));
	 	} 	

	 	if (isset($_POST['adsense_code5']) ) {
	 			update_option('adsense_code5',stripslashes($_POST['adsense_code5']));
	 	}

		if (isset($_POST['adsense_code_mobile'])) {
				update_option('adsense_code_mobile',stripslashes($_POST['adsense_code_mobile']));
		} 

		if (isset($_POST['adsense_code_mobile2'])) {	 	
				update_option('adsense_code_mobile2',stripslashes($_POST['adsense_code_mobile2']));
 		} 

 		if (isset($_POST['adsense_code_mobile3'])) {	 	
				update_option('adsense_code_mobile3',stripslashes($_POST['adsense_code_mobile3']));
 		} 

 		if (isset($_POST['adsense_code_mobile4'])) {	 	
				update_option('adsense_code_mobile4',stripslashes($_POST['adsense_code_mobile4']));
 		} 

 		if (isset($_POST['adsense_code_mobile5'])) {	 	
				update_option('adsense_code_mobile5',stripslashes($_POST['adsense_code_mobile5']));
 		} 

		wp_safe_redirect(menu_page_url('my-subemenu',false));
	}

	function add_custom_whitelist_options_fields() {
	    register_setting( 'general', 'adsense_code' );
	}

	function add_ads_before_1st_h3($the_content) {
       
       $esctag = get_option('escape_tag');

	   if ( is_single()) {

	   	// has_tag("") = true

		   if (empty($esctag) || (!empty($esctag) && !has_tag($esctag))) {	
			//モバイルの場合はモバイル用の広告を出力
			if (wp_is_mobile() ) {
				$ad_template = get_option('adsense_code_mobile');
				$ad_template2 = get_option('adsense_code_mobile2');
				$ad_template3 = get_option('adsense_code_mobile3');
				$ad_template4 = get_option('adsense_code_mobile4');
				$ad_template5 = get_option('adsense_code_mobile5');
			} else {
		    	$ad_template = get_option('adsense_code');
		    	$ad_template2 = get_option('adsense_code2');
		    	$ad_template3 = get_option('adsense_code3');
		    	$ad_template4 = get_option('adsense_code4');
		    	$ad_template5 = get_option('adsense_code5');
			}
		    
			//指定されたタグにあわせてリプレイスする広告を選ぶ
		    if (get_option('tagtype') == "h2tag" ) {
		    	preg_match_all( H2_REG, $the_content, $h3results);
			} else if (get_option('tagtype') == "h3tag" ) {
				preg_match_all( H3_REG, $the_content, $h3results);
			} else if (get_option('tagtype') == "h4tag" ) {
				preg_match_all( H4_REG, $the_content, $h3results);
		  	}

		    if ( !empty( $h3results ) ) {
				$h3result = $h3results[0];
				//指定タグの上に出力する場合
		    	if (get_option('taglocate') == "above") {
				//タグの出力位置。何番目のタグかで判断
		    	  		$the_content = str_replace($h3result[0], $ad_template.$h3result[0], $the_content);
		    			$the_content = str_replace($h3result[1], $ad_template2.$h3result[1], $the_content);
		    			$the_content = str_replace($h3result[2], $ad_template3.$h3result[2], $the_content);
		    			$the_content = str_replace($h3result[3], $ad_template3.$h3result[3], $the_content);
		    			$the_content = str_replace($h3result[4], $ad_template3.$h3result[4], $the_content);
				//指定タグの下に出力する場合
		    	} else {
		    			$the_content = str_replace($h3result[0], $h3result[0].$ad_template, $the_content);
		    			$the_content = str_replace($h3result[1], $h3result[1].$ad_template2, $the_content);
		    			$the_content = str_replace($h3result[2], $h3result[2].$ad_template3, $the_content);	
		    			$the_content = str_replace($h3result[3], $h3result[3].$ad_template2, $the_content);
		    			$the_content = str_replace($h3result[4], $h3result[4].$ad_template3, $the_content);	
		  			}
				}
			}
		}
	  	return $the_content;
	}
	
	function my_uninstall_hook() {
	    	delete_option('adsense_seting');
	}
}
?>